lilypondfiletools.PaperBlock
============================

.. abjad-lineage:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock

.. autoclass:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.is_formatted_when_empty
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.minimal_page_breaking
   :noindex:

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.append
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.count
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.extend
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.index
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.insert
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.pop
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.remove
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.reverse
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.sort
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__add__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__contains__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__delitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__delslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__getitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__getslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__iadd__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__imul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__iter__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__len__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__mul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__repr__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__reversed__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__rmul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__setitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__setslice__
   :noindex:
